
The API for SkoloCFD
============================

skolo is the SkoloCFD Software Development Kit (SDK) for Python


Getting Started
---------------
You can install the library on linux using ``pip``

    $ python -m pip install skolo

Or from the windows command prompt with:

    $ py -m pip install skolo

Or, assuming that you have Python and ``virtualenv`` installed, set up your environment and install the required dependencies like this:

    $ git clone https://github.com/skoloCFD/skolo
    $ cd skolo
    $ virtualenv venv
    ...
    $ . venv/bin/activate
    $ python -m pip install -r requirements.txt
    $ python -m pip install -e .



Configuring Skolo
------------
After installing skolo, you'll need to provide it credential access to the Skolo web server. Instructions for this can be found on the documentation page of the website.


Release Notes
------------
####v0.1.4 - December 2024
- new options for creating cases
- ability to connect to custom server, including on local networks